@@ -71,7 +71,37 @@ utils::globalVariables(
     "df",
     "p-value",
     "chi_sq",
-    "significance"
+    "significance",
+    "F-value",
+    "V2",
+    "V3",
+    "V4",
+    "V5",
+    "conf",
+    "AIC",
+    "BIC",
+    "R",
+    "adj.r.squared",
+    "p.value",
+    "term",
+    "label",
+    "loglik",
+    "Pr(>|t|)",
+    "coef",
+    "conf.high",
+    "conf.low",
+    "rowid",
+    "Cramer's V",
+    "df[chiSq]",
+    "p[chiSq]",
+    "value[chiSq]",
+    "condition_n_label",
+    "total_n",
+    "robust",
+    "partial.etasq",
+    "partial.omegasq",
+    "stratum",
+    "coefficient_type"
   ),
   package = "ggstatsplot",
   add = FALSE
